@@ -28,6 +28,7 @@ import org.apache.bookkeeper.http.HttpServer;
  */
 public class HttpServiceResponse {
     private String body;
+    private String contentType;
     private HttpServer.StatusCode code = HttpServer.StatusCode.OK;
 
     public HttpServiceResponse() {}
@@ -41,6 +42,10 @@ public class HttpServiceResponse {
         return body;
     }
 
+    public String getContentType() {
+        return contentType;
+    }
+
     public int getStatusCode() {
         return code.getValue();
     }
@@ -50,6 +55,11 @@ public class HttpServiceResponse {
         return this;
     }
 
+    public HttpServiceResponse setContentType(String contentType) {
+        this.contentType = contentType;
+        return this;
+    }
+
     public HttpServiceResponse setCode(HttpServer.StatusCode code) {
         this.code = code;
         return this;
