@@ -1,4 +1,4 @@
-/**
+/*
  *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -50,6 +50,7 @@ import org.apache.bookkeeper.util.BookKeeperConstants;
 import org.apache.bookkeeper.versioning.LongVersion;
 import org.apache.bookkeeper.versioning.Version;
 import org.apache.bookkeeper.versioning.Versioned;
+import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -68,20 +69,23 @@ import org.slf4j.LoggerFactory;
 public class Cookie {
     private static final Logger LOG = LoggerFactory.getLogger(Cookie.class);
 
-    static final int CURRENT_COOKIE_LAYOUT_VERSION = 4;
+    static final int CURRENT_COOKIE_LAYOUT_VERSION = 5;
     private final int layoutVersion;
     private final String bookieId;
     private final String journalDirs;
     private final String ledgerDirs;
+    private final String indexDirs;
     private final String instanceId;
     private static final String SEPARATOR = "\t";
 
-    private Cookie(int layoutVersion, String bookieId, String journalDirs, String ledgerDirs, String instanceId) {
+    private Cookie(int layoutVersion, String bookieId, String journalDirs, String ledgerDirs, String instanceId,
+                   String indexDirs) {
         this.layoutVersion = layoutVersion;
         this.bookieId = bookieId;
         this.journalDirs = journalDirs;
         this.ledgerDirs = ledgerDirs;
         this.instanceId = instanceId;
+        this.indexDirs = indexDirs;
     }
 
     public static String encodeDirPaths(String[] dirs) {
@@ -104,6 +108,13 @@ public class Cookie {
         return decodeDirPathFromCookie(ledgerDirs);
     }
 
+    String[] getIndexDirPathsFromCookie() {
+        if (null == indexDirs) {
+            return null;
+        }
+        return decodeDirPathFromCookie(indexDirs);
+    }
+
     /**
      * Receives 2 String arrays, that each contain a list of directory paths,
      * and checks if first is a super set of the second.
@@ -126,6 +137,18 @@ public class Cookie {
         }
     }
 
+    private boolean verifyIndexDirs(Cookie c, boolean checkIfSuperSet) {
+        // compatible logic:  existed node's cookie has no indexDirs, the indexDirs's default value is ledgerDirs.
+        String indexDirsInConfig = StringUtils.isNotBlank(indexDirs) ? indexDirs : ledgerDirs;
+        String indexDirsInCookie = StringUtils.isNotBlank(c.indexDirs) ? c.indexDirs : c.ledgerDirs;
+
+        if (!checkIfSuperSet) {
+            return indexDirsInConfig.equals(indexDirsInCookie);
+        } else {
+            return isSuperSet(decodeDirPathFromCookie(indexDirsInConfig), decodeDirPathFromCookie(indexDirsInCookie));
+        }
+    }
+
     private void verifyInternal(Cookie c, boolean checkIfSuperSet) throws BookieException.InvalidCookieException {
         String errMsg;
         if (c.layoutVersion < 3 && c.layoutVersion != layoutVersion) {
@@ -133,7 +156,8 @@ public class Cookie {
             LOG.error(errMsg);
             throw new BookieException.InvalidCookieException(errMsg);
         } else if (!(c.layoutVersion >= 3 && c.bookieId.equals(bookieId)
-            && c.journalDirs.equals(journalDirs) && verifyLedgerDirs(c, checkIfSuperSet))) {
+            && c.journalDirs.equals(journalDirs) && verifyLedgerDirs(c, checkIfSuperSet)
+            && verifyIndexDirs(c, checkIfSuperSet))) {
             errMsg = "Cookie [" + this + "] is not matching with [" + c + "]";
             throw new BookieException.InvalidCookieException(errMsg);
         } else if ((instanceId == null && c.instanceId != null)
@@ -165,9 +189,13 @@ public class Cookie {
         if (null != instanceId) {
             builder.setInstanceId(instanceId);
         }
+        if (null != indexDirs) {
+            builder.setIndexDirs(indexDirs);
+        }
+
         StringBuilder b = new StringBuilder();
         b.append(CURRENT_COOKIE_LAYOUT_VERSION).append("\n");
-        b.append(builder.build().toString());
+        b.append(builder.build());
         return b.toString();
     }
 
@@ -209,6 +237,9 @@ public class Cookie {
             if (null != data.getInstanceId() && !data.getInstanceId().isEmpty()) {
                 cBuilder.setInstanceId(data.getInstanceId());
             }
+            if (null != data.getIndexDirs() && !data.getIndexDirs().isEmpty()) {
+                cBuilder.setIndexDirs(data.getIndexDirs());
+            }
         }
         return cBuilder;
     }
@@ -304,6 +335,9 @@ public class Cookie {
         builder.setBookieId(BookieImpl.getBookieId(conf).toString());
         builder.setJournalDirs(Joiner.on(',').join(conf.getJournalDirNames()));
         builder.setLedgerDirs(encodeDirPaths(conf.getLedgerDirNames()));
+        if (null != conf.getIndexDirNames()) {
+            builder.setIndexDirs(encodeDirPaths(conf.getIndexDirNames()));
+        }
         return builder;
     }
 
@@ -398,17 +432,19 @@ public class Cookie {
         private String journalDirs = null;
         private String ledgerDirs = null;
         private String instanceId = null;
+        private String indexDirs = null;
 
         private Builder() {
         }
 
         private Builder(int layoutVersion, String bookieId, String journalDirs, String ledgerDirs,
-                        String instanceId) {
+                        String instanceId, String indexDirs) {
             this.layoutVersion = layoutVersion;
             this.bookieId = bookieId;
             this.journalDirs = journalDirs;
             this.ledgerDirs = ledgerDirs;
             this.instanceId = instanceId;
+            this.indexDirs = indexDirs;
         }
 
         public Builder setLayoutVersion(int layoutVersion) {
@@ -436,8 +472,13 @@ public class Cookie {
             return this;
         }
 
+        public Builder setIndexDirs(String indexDirs) {
+            this.indexDirs = indexDirs;
+            return this;
+        }
+
         public Cookie build() {
-            return new Cookie(layoutVersion, bookieId, journalDirs, ledgerDirs, instanceId);
+            return new Cookie(layoutVersion, bookieId, journalDirs, ledgerDirs, instanceId, indexDirs);
         }
     }
 
@@ -458,7 +499,7 @@ public class Cookie {
      */
     public static Builder newBuilder(Cookie oldCookie) {
         return new Builder(oldCookie.layoutVersion, oldCookie.bookieId, oldCookie.journalDirs, oldCookie.ledgerDirs,
-                oldCookie.instanceId);
+                oldCookie.instanceId, oldCookie.indexDirs);
     }
 
     @Override
@@ -469,7 +510,8 @@ public class Cookie {
                 && Objects.equals(bookieId, otherCookie.bookieId)
                 && Objects.equals(journalDirs, otherCookie.journalDirs)
                 && Objects.equals(ledgerDirs, otherCookie.ledgerDirs)
-                && Objects.equals(instanceId, otherCookie.instanceId);
+                && Objects.equals(instanceId, otherCookie.instanceId)
+                && Objects.equals(indexDirs, otherCookie.indexDirs);
         } else {
             return false;
         }
@@ -477,6 +519,6 @@ public class Cookie {
 
     @Override
     public int hashCode() {
-        return Objects.hash(bookieId, journalDirs, ledgerDirs, instanceId);
+        return Objects.hash(bookieId, journalDirs, ledgerDirs, instanceId, indexDirs);
     }
 }
