@@ -53,6 +53,11 @@ public interface StateManager extends AutoCloseable {
      */
     boolean isForceReadOnly();
 
+    /**
+     * Check is readOnlyModeEnabled.
+     */
+    boolean isReadOnlyModeEnabled();
+
     /**
      * Check is Running.
      */
