@@ -28,7 +28,6 @@ import java.util.Arrays;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
-
 import org.apache.bookkeeper.client.AsyncCallback.OpenCallback;
 import org.apache.bookkeeper.client.AsyncCallback.ReadLastConfirmedCallback;
 import org.apache.bookkeeper.client.BookKeeper.DigestType;
@@ -40,7 +39,6 @@ import org.apache.bookkeeper.client.impl.OpenBuilderBase;
 import org.apache.bookkeeper.stats.OpStatsLogger;
 import org.apache.bookkeeper.util.MathUtils;
 import org.apache.bookkeeper.util.OrderedGenericCallback;
-import org.apache.bookkeeper.util.SafeRunnable;
 import org.apache.bookkeeper.versioning.Versioned;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -257,12 +255,7 @@ class LedgerOpenOp {
         }
 
         if (lh != null) { // lh is null in case of errors
-            lh.executeOrdered(new SafeRunnable() {
-                @Override
-                public void safeRun() {
-                    cb.openComplete(rc, lh, ctx);
-                }
-            });
+            lh.executeOrdered(() -> cb.openComplete(rc, lh, ctx));
         } else {
             cb.openComplete(rc, null, ctx);
         }
