@@ -824,12 +824,17 @@ abstract class TopologyAwareEnsemblePlacementPolicy implements
             if (null != historyBookie) {
                 return historyBookie.getNetworkLocation();
             }
+            String defaultRack = getDefaultRack();
             LOG.error("Cannot resolve bookieId {} to a network address, resolving as {}. {}", addr,
-                      NetworkTopology.DEFAULT_REGION_AND_RACK, err.getMessage());
-            return NetworkTopology.DEFAULT_REGION_AND_RACK;
+                    defaultRack, err.getMessage());
+            return defaultRack;
         }
     }
 
+    protected String getDefaultRack() {
+        return NetworkTopology.DEFAULT_REGION_AND_RACK;
+    }
+
     protected Set<Node> convertBookiesToNodes(Collection<BookieId> bookies) {
         Set<Node> nodes = new HashSet<Node>();
         for (BookieId addr : bookies) {
