@@ -45,6 +45,23 @@ public interface ReadHandle extends Handle {
      */
     CompletableFuture<LedgerEntries> readAsync(long firstEntry, long lastEntry);
 
+    /**
+     * Read a sequence of entries asynchronously.
+     *
+     * @param startEntry
+     *          start entry id
+     * @param maxCount
+     *          the total entries count.
+     * @param maxSize
+     *          the total entries size.
+     * @return an handle to the result of the operation
+     */
+    default CompletableFuture<LedgerEntries> batchReadAsync(long startEntry, int maxCount, long maxSize) {
+        CompletableFuture<LedgerEntries> future = new CompletableFuture<>();
+        future.completeExceptionally(new UnsupportedOperationException());
+        return future;
+    }
+
     /**
      * Read a sequence of entries synchronously.
      *
@@ -59,6 +76,21 @@ public interface ReadHandle extends Handle {
                                                               BKException.HANDLER);
     }
 
+    /**
+     *
+     * @param startEntry
+     *          start entry id
+     * @param maxCount
+     *          the total entries count.
+     * @param maxSize
+     *          the total entries size.
+     * @return the result of the operation
+     */
+    default LedgerEntries batchRead(long startEntry, int maxCount, long maxSize)
+            throws BKException, InterruptedException {
+        return FutureUtils.result(batchReadAsync(startEntry, maxCount, maxSize), BKException.HANDLER);
+    }
+
     /**
      * Read a sequence of entries asynchronously, allowing to read after the LastAddConfirmed range.
      * <br>This is the same of
