@@ -30,6 +30,7 @@ import com.google.common.collect.Lists;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 import java.util.UUID;
@@ -109,17 +110,16 @@ public class ZKRegistrationManager implements RegistrationManager {
     protected final String bookieReadonlyRegistrationPath;
     // session timeout in milliseconds
     private final int zkTimeoutMs;
+    private final List<RegistrationListener> listeners = new ArrayList<>();
 
     public ZKRegistrationManager(ServerConfiguration conf,
-                                 ZooKeeper zk,
-                                 RegistrationListener listener) {
-        this(conf, zk, ZKMetadataDriverBase.resolveZkLedgersRootPath(conf), listener);
+                                 ZooKeeper zk) {
+        this(conf, zk, ZKMetadataDriverBase.resolveZkLedgersRootPath(conf));
     }
 
     public ZKRegistrationManager(ServerConfiguration conf,
                                  ZooKeeper zk,
-                                 String ledgersRootPath,
-                                 RegistrationListener listener) {
+                                 String ledgersRootPath) {
         this.conf = conf;
         this.zk = zk;
         this.zkAcls = ZkUtils.getACLs(conf);
@@ -142,7 +142,7 @@ public class ZKRegistrationManager implements RegistrationManager {
             // Check for expired connection.
             if (event.getType().equals(EventType.None)
                 && event.getState().equals(KeeperState.Expired)) {
-                listener.onRegistrationExpired();
+                listeners.forEach(RegistrationListener::onRegistrationExpired);
             }
         });
     }
@@ -610,4 +610,9 @@ public class ZKRegistrationManager implements RegistrationManager {
             throw new MetadataStoreException(e);
         }
     }
+
+    @Override
+    public void addRegistrationListener(RegistrationListener listener) {
+        listeners.add(listener);
+    }
 }
