@@ -18,6 +18,7 @@
  */
 package org.apache.bookkeeper.meta.zk;
 
+import com.google.common.annotations.VisibleForTesting;
 import java.util.Optional;
 import java.util.concurrent.ScheduledExecutorService;
 import lombok.extern.slf4j.Slf4j;
@@ -31,6 +32,7 @@ import org.apache.bookkeeper.stats.StatsLogger;
 import org.apache.bookkeeper.zookeeper.BoundExponentialBackoffRetryPolicy;
 import org.apache.zookeeper.Watcher.Event.EventType;
 import org.apache.zookeeper.Watcher.Event.KeeperState;
+import org.apache.zookeeper.ZooKeeper;
 
 /**
  * ZooKeeper based metadata client driver.
@@ -76,15 +78,21 @@ public class ZKMetadataClientDriver
     @Override
     public synchronized RegistrationClient getRegistrationClient() {
         if (null == regClient) {
-            regClient = new ZKRegistrationClient(
-                zk,
-                ledgersRootPath,
-                scheduler,
-                bookieAddressTracking);
+            regClient = newZKRegistrationClient(
+                    zk,
+                    ledgersRootPath,
+                    scheduler,
+                    bookieAddressTracking);
         }
         return regClient;
     }
 
+    @VisibleForTesting
+    ZKRegistrationClient newZKRegistrationClient(ZooKeeper zk, String ledgersRootPath,
+                                                 ScheduledExecutorService scheduler, boolean bookieAddressTracking) {
+        return new ZKRegistrationClient(zk, ledgersRootPath, scheduler, bookieAddressTracking);
+    }
+
     @Override
     public synchronized void close() {
         if (null != regClient) {
