@@ -1,4 +1,4 @@
-/**
+/*
  *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -20,7 +20,7 @@
  */
 package org.apache.bookkeeper.processor;
 
-import io.netty.channel.Channel;
+import org.apache.bookkeeper.proto.BookieRequestHandler;
 
 /**
  * A request processor that is used for processing requests at bookie side.
@@ -41,5 +41,5 @@ public interface RequestProcessor extends AutoCloseable {
      * @param channel
      *          channel received the given request <i>r</i>
      */
-    void processRequest(Object r, Channel channel);
+    void processRequest(Object r, BookieRequestHandler channel);
 }
