@@ -22,6 +22,7 @@ import static org.apache.bookkeeper.common.concurrent.FutureUtils.result;
 import static org.apache.bookkeeper.tools.cli.helpers.CommandHelpers.getBookieSocketAddrStringRepresentation;
 
 import com.beust.jcommander.Parameter;
+import com.google.common.annotations.VisibleForTesting;
 import java.util.Collection;
 import java.util.Set;
 import lombok.Setter;
@@ -48,7 +49,7 @@ public class ListBookiesCommand extends DiscoveryCommand<Flags> {
     private static final Logger LOG = LoggerFactory.getLogger(ListBookiesCommand.class);
 
     public ListBookiesCommand() {
-        this(new Flags());
+        this(Flags.newFlags());
     }
 
     public ListBookiesCommand(Flags flags) {
@@ -59,6 +60,11 @@ public class ListBookiesCommand extends DiscoveryCommand<Flags> {
             .build());
     }
 
+    @VisibleForTesting
+    public static ListBookiesCommand newListBookiesCommand(Flags flags) {
+        return new ListBookiesCommand(flags);
+    }
+
     /**
      * Flags for list bookies command.
      */
@@ -73,6 +79,11 @@ public class ListBookiesCommand extends DiscoveryCommand<Flags> {
         @Parameter(names = { "-a", "--all" }, description = "Print all bookies")
         private boolean all = false;
 
+        @VisibleForTesting
+        public static Flags newFlags(){
+            return new Flags();
+        }
+
     }
 
     @Override
