@@ -23,14 +23,16 @@ package org.apache.bookkeeper.bookie;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyLong;
+import static org.mockito.ArgumentMatchers.nullable;
 import static org.mockito.Mockito.atLeast;
 import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
-import static org.powermock.api.mockito.PowerMockito.whenNew;
 
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.Unpooled;
@@ -53,18 +55,13 @@ import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 import org.junit.runner.RunWith;
 import org.mockito.invocation.InvocationOnMock;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
-import org.powermock.core.classloader.annotations.PowerMockIgnore;
-import org.powermock.core.classloader.annotations.PrepareForTest;
-import org.powermock.modules.junit4.PowerMockRunner;
-import org.powermock.reflect.Whitebox;
 
 /**
  * Test the bookie journal.
  */
-@RunWith(PowerMockRunner.class)
-@PowerMockIgnore({"javax.xml.*", "org.xml.*", "org.w3c.*", "javax.xml.*", "com.sun.org.apache.xerces.*"})
-@PrepareForTest({JournalChannel.class, Journal.class, DefaultFileChannel.class})
+@RunWith(MockitoJUnitRunner.class)
 @Slf4j
 public class BookieJournalForceTest {
 
@@ -83,17 +80,17 @@ public class BookieJournalForceTest {
             .setMetadataServiceUri(null)
             .setJournalAdaptiveGroupWrites(false);
 
-        JournalChannel jc = spy(new JournalChannel(journalDir, 1));
-        whenNew(JournalChannel.class).withAnyArguments().thenReturn(jc);
-
         LedgerDirsManager ledgerDirsManager = mock(LedgerDirsManager.class);
         Journal journal = new Journal(0, journalDir, conf, ledgerDirsManager);
-
         // machinery to suspend ForceWriteThread
         CountDownLatch forceWriteThreadSuspendedLatch = new CountDownLatch(1);
         BatchedArrayBlockingQueue<ForceWriteRequest> supportQueue =
                 enableForceWriteThreadSuspension(forceWriteThreadSuspendedLatch, journal);
 
+        journal = spy(journal);
+        JournalChannel jc = spy(new JournalChannel(journalDir, 1));
+        doReturn(jc).when(journal).newLogFile(anyLong(), nullable(Long.class));
+
         journal.start();
 
         LogMark lastLogMarkBeforeWrite = journal.getLastLogMark().markLog().getCurMark();
@@ -146,15 +143,17 @@ public class BookieJournalForceTest {
             .setMetadataServiceUri(null)
             .setJournalAdaptiveGroupWrites(false);
 
-        JournalChannel jc = spy(new JournalChannel(journalDir, 1));
-        whenNew(JournalChannel.class).withAnyArguments().thenReturn(jc);
-
         LedgerDirsManager ledgerDirsManager = mock(LedgerDirsManager.class);
         Journal journal = new Journal(0, journalDir, conf, ledgerDirsManager);
-
         // machinery to suspend ForceWriteThread
         CountDownLatch forceWriteThreadSuspendedLatch = new CountDownLatch(1);
-        enableForceWriteThreadSuspension(forceWriteThreadSuspendedLatch, journal);
+        BatchedArrayBlockingQueue<ForceWriteRequest> supportQueue =
+                enableForceWriteThreadSuspension(forceWriteThreadSuspendedLatch, journal);
+
+        journal = spy(journal);
+        JournalChannel jc = spy(new JournalChannel(journalDir, 1));
+        doReturn(jc).when(journal).newLogFile(anyLong(), nullable(Long.class));
+
         journal.start();
 
         LogMark lastLogMarkBeforeWrite = journal.getLastLogMark().markLog().getCurMark();
@@ -202,21 +201,21 @@ public class BookieJournalForceTest {
             .setMetadataServiceUri(null)
             .setJournalAdaptiveGroupWrites(false);
 
-        JournalChannel jc = spy(new JournalChannel(journalDir, 1));
-        whenNew(JournalChannel.class).withAnyArguments().thenReturn(jc);
-
         LedgerDirsManager ledgerDirsManager = mock(LedgerDirsManager.class);
         Journal journal = new Journal(0, journalDir, conf, ledgerDirsManager);
-
         // machinery to suspend ForceWriteThread
         CountDownLatch forceWriteThreadSuspendedLatch = new CountDownLatch(1);
         enableForceWriteThreadSuspension(forceWriteThreadSuspendedLatch, journal);
 
+        journal = spy(journal);
+        JournalChannel jc = spy(new JournalChannel(journalDir, 1));
+        doReturn(jc).when(journal).newLogFile(anyLong(), nullable(Long.class));
+
         JournalStats journalStats = journal.getJournalStats();
         TestStatsProvider testStatsProvider = new TestStatsProvider();
         Counter flushMaxOutstandingBytesCounter = testStatsProvider.getStatsLogger("test")
                                                         .getCounter("flushMaxOutstandingBytesCounter");
-        Whitebox.setInternalState(journalStats, "flushMaxOutstandingBytesCounter", flushMaxOutstandingBytesCounter);
+        journalStats.setFlushMaxOutstandingBytesCounter(flushMaxOutstandingBytesCounter);
 
         journal.start();
 
@@ -263,10 +262,11 @@ public class BookieJournalForceTest {
             .setMetadataServiceUri(null);
 
         JournalChannel jc = spy(new JournalChannel(journalDir, 1));
-        whenNew(JournalChannel.class).withAnyArguments().thenReturn(jc);
 
         LedgerDirsManager ledgerDirsManager = mock(LedgerDirsManager.class);
-        Journal journal = new Journal(0, journalDir, conf, ledgerDirsManager);
+        Journal journal = spy(new Journal(0, journalDir, conf, ledgerDirsManager));
+        doReturn(jc).when(journal).newLogFile(anyLong(), nullable(Long.class));
+
         journal.start();
 
         final int numEntries = 100;
@@ -316,7 +316,7 @@ public class BookieJournalForceTest {
             ForceWriteRequest[] array = iom.getArgument(0);
             return supportQueue.takeAll(array);
         }).when(forceWriteRequests).takeAll(any());
-        Whitebox.setInternalState(journal, "forceWriteRequests", forceWriteRequests);
+        journal.setForceWriteRequests(forceWriteRequests);
         return supportQueue;
     }
 
@@ -329,16 +329,17 @@ public class BookieJournalForceTest {
         conf.setJournalDirName(journalDir.getPath());
         conf.setJournalAdaptiveGroupWrites(false);
 
-        JournalChannel jc = spy(new JournalChannel(journalDir, 1));
-        whenNew(JournalChannel.class).withAnyArguments().thenReturn(jc);
-
         LedgerDirsManager ledgerDirsManager = mock(LedgerDirsManager.class);
         Journal journal = new Journal(0, journalDir, conf, ledgerDirsManager);
-
         // machinery to suspend ForceWriteThread
         CountDownLatch forceWriteThreadSuspendedLatch = new CountDownLatch(1);
         BatchedArrayBlockingQueue<ForceWriteRequest> supportQueue =
                 enableForceWriteThreadSuspension(forceWriteThreadSuspendedLatch, journal);
+
+        JournalChannel jc = spy(new JournalChannel(journalDir, 1));
+        journal = spy(journal);
+        doReturn(jc).when(journal).newLogFile(anyLong(), nullable(Long.class));
+
         journal.start();
 
         LogMark lastLogMarkBeforeWrite = journal.getLastLogMark().markLog().getCurMark();
