@@ -25,8 +25,6 @@ import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
@@ -37,6 +35,7 @@ import org.apache.bookkeeper.client.api.BKException.Code;
 import org.apache.bookkeeper.client.api.OpenBuilder;
 import org.apache.bookkeeper.client.api.ReadHandle;
 import org.apache.bookkeeper.client.impl.OpenBuilderBase;
+import org.apache.bookkeeper.common.util.OrderedExecutor;
 import org.apache.bookkeeper.conf.ClientConfiguration;
 import org.apache.zookeeper.ZooKeeper;
 import org.slf4j.Logger;
@@ -49,7 +48,10 @@ import org.slf4j.LoggerFactory;
  */
 public class MockBookKeeper extends BookKeeper {
 
-    final ExecutorService executor = Executors.newFixedThreadPool(1, new DefaultThreadFactory("mock-bookkeeper"));
+    final OrderedExecutor orderedExecutor = OrderedExecutor.newBuilder()
+            .numThreads(1)
+            .threadFactory(new DefaultThreadFactory("mock-bookkeeper"))
+            .build();
     final ZooKeeper zkc;
 
     @Override
@@ -68,6 +70,11 @@ public class MockBookKeeper extends BookKeeper {
         this.zkc = zkc;
     }
 
+    @Override
+    public OrderedExecutor getMainWorkerPool() {
+        return orderedExecutor;
+    }
+
     @Override
     public LedgerHandle createLedger(DigestType digestType, byte[] passwd) throws BKException {
         return createLedger(3, 2, digestType, passwd);
@@ -86,7 +93,7 @@ public class MockBookKeeper extends BookKeeper {
             return;
         }
 
-        executor.execute(new Runnable() {
+        orderedExecutor.chooseThread().execute(new Runnable() {
             public void run() {
                 if (getProgrammedFailStatus()) {
                     if (failReturnCode != BkTimeoutOperation) {
@@ -256,7 +263,7 @@ public class MockBookKeeper extends BookKeeper {
         }
 
         ledgers.clear();
-        executor.shutdownNow();
+        orderedExecutor.shutdownNow();
     }
 
     public boolean isStopped() {
