@@ -24,10 +24,8 @@ import io.netty.buffer.ByteBuf;
 import io.netty.buffer.ByteBufAllocator;
 import io.netty.buffer.Unpooled;
 import io.netty.util.ReferenceCountUtil;
-
 import java.util.concurrent.ThreadLocalRandom;
 import java.util.concurrent.TimeUnit;
-
 import org.apache.bookkeeper.proto.BookieProtoEncoding.EnDecoder;
 import org.apache.bookkeeper.proto.BookieProtoEncoding.RequestEnDeCoderPreV3;
 import org.apache.bookkeeper.proto.BookieProtoEncoding.RequestEnDecoderV3;
@@ -81,22 +79,6 @@ public class ProtocolBenchmark {
         this.reqEnDeV3 = new RequestEnDecoderV3(null);
     }
 
-
-    @Benchmark
-    public void testAddEntryV2() throws Exception {
-        ByteBufList list = ByteBufList.get(entry.retainedSlice());
-        BookieProtocol.AddRequest req = BookieProtocol.AddRequest.create(
-                BookieProtocol.CURRENT_PROTOCOL_VERSION,
-                ledgerId,
-                entryId,
-                flags,
-                masterKey,
-                list);
-        Object res = this.reqEnDeV2.encode(req, ByteBufAllocator.DEFAULT);
-        ReferenceCountUtil.release(res);
-        ReferenceCountUtil.release(list);
-    }
-
     @Benchmark
     public void testAddEntryV3() throws Exception {
         // Build the request and calculate the total size to be included in the packet.
