@@ -15,7 +15,7 @@
 package org.apache.bookkeeper.stream.server.conf;
 
 import org.apache.bookkeeper.common.conf.ComponentConfiguration;
-import org.apache.commons.configuration.CompositeConfiguration;
+import org.apache.commons.configuration2.CompositeConfiguration;
 
 /**
  * KeyRange Server related configuration withSettings.
@@ -25,6 +25,8 @@ public class StorageServerConfiguration extends ComponentConfiguration {
     private static final String COMPONENT_PREFIX = "storageserver" + DELIMITER;
 
     private static final String GRPC_PORT = "grpc.port";
+    private static final String GRPC_USE_HOSTNAME = "grpc.useHostname";
+
 
     public static StorageServerConfiguration of(CompositeConfiguration conf) {
         return new StorageServerConfiguration(conf);
@@ -42,4 +44,14 @@ public class StorageServerConfiguration extends ComponentConfiguration {
     public int getGrpcPort() {
         return getInt(GRPC_PORT, 4181);
     }
+
+    /**
+     * Returns the grpc flag that indicates to use hostname instead of IP address
+     * for the stream storage server.
+     *
+     * @return grpc useHostname flag
+     */
+    public boolean getGrpcUseHostname() {
+        return getBoolean(GRPC_USE_HOSTNAME, false);
+    }
 }
